==> mix_V00.03.99.src.tgz: proxytest/CAAccountingControlChannel.hpp <==
/*
Copyright (c) 2000, The JAP-Team 
All rights reserved.
Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

	- Redistributions of source code must retain the above copyright notice, 
	  this list of conditions and the following disclaimer.

	- Redistributions in binary form must reproduce the above copyright notice, 
	  this list of conditions and the following disclaimer in the documentation and/or 
		other materials provided with the distribution.

	- Neither the name of the University of Technology Dresden, Germany nor the names of its contributors 
	  may be used to endorse or promote products derived from this software without specific 
		prior written permission. 

	
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS'' AND ANY EXPRESS 
OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY 
AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER 
IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE
*/

#ifndef __CAACCOUNTINGCONTROLCHANNEL_HPP
#define __CAACCOUNTINGCONTROLCHANNEL_HPP

#include "CAAccountingInstance.hpp"
#include "CASyncControlChannel.hpp"
#include "CAFirstMixChannelList.hpp"

class CAAccountingInstance;

/**
implementation of a per-user control-channel for the AccountingInstance. 
All incoming messages are appended to the AccountingInstance queue where 
they are processed in an own thread.

@author Bastian Voigt
*/
class CAAccountingControlChannel : public CASyncControlChannel
{
public:
    CAAccountingControlChannel(fmHashTableEntry * pHashEntry);
		
    virtual ~CAAccountingControlChannel();
		
		virtual SINT32 processXMLMessage(const DOM_Document &a_doc);

private:
		fmHashTableEntry * m_pHashEntry;
		static CAAccountingInstance * ms_pAccountingInstance;
};

#endif

==> mix_V00.05.38.src.tgz: proxytest/CAAccountingControlChannel.hpp <==
/*
Copyright (c) 2000, The JAP-Team 
All rights reserved.
Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

	- Redistributions of source code must retain the above copyright notice, 
	  this list of conditions and the following disclaimer.

	- Redistributions in binary form must reproduce the above copyright notice, 
	  this list of conditions and the following disclaimer in the documentation and/or 
		other materials provided with the distribution.

	- Neither the name of the University of Technology Dresden, Germany nor the names of its contributors 
	  may be used to endorse or promote products derived from this software without specific 
		prior written permission. 

	
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS'' AND ANY EXPRESS 
OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY 
AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER 
IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE
*/

#ifndef __CAACCOUNTINGCONTROLCHANNEL_HPP
#define __CAACCOUNTINGCONTROLCHANNEL_HPP

#include "CAAccountingInstance.hpp"
#include "CASyncControlChannel.hpp"
#include "CAFirstMixChannelList.hpp"

/**
implementation of a per-user control-channel for the AccountingInstance. 
All incoming messages are appended to the AccountingInstance queue where 
they are processed in an own thread.

@author Bastian Voigt
*/
class CAAccountingControlChannel : public CASyncControlChannel
	{
		public:
			CAAccountingControlChannel(fmHashTableEntry * pHashEntry);
			virtual ~CAAccountingControlChannel();
			SINT32 processXMLMessage(const DOM_Document &a_doc);

		private:
			fmHashTableEntry * m_pHashEntry;
	};
#endif
